@@ -9,6 +9,7 @@ import argparse
 import numpy as np
 import os
 import requests
+import sys
 
 import warnings
 warnings.filterwarnings("ignore", ".*GUI is implemented.*")
@@ -49,21 +50,16 @@ def ac_mode_func(args):
         message += '\nHeaders in the input file are not recognised.'
         message += '\nRefer to manual to see valid options, and contact'
         message += ' danielreta1@gmail.com to implement new headers.'
-        gui.error_box(message)
+        if args.ccfit2_exe:
+            gui.error_box(message)
+        else:
+            sys.exit(message)
 
     # Load data from file as unordered list of individual Measurements
     ac_measurements = ac.Measurement.from_file(
         user_cfg.file_name, header_indices, data_header=args.data_pointer
     )
 
-    if args.verbose:
-        print("\nRaw Temperatures (K)")
-        for meas in ac_measurements:
-            print(meas.temperature)
-        print("\n\nRaw DC Field (Oe)")
-        for meas in ac_measurements:
-            print(meas.dc_field)
-
     # Change of units of input susceptibility to cm^3mol^(-1)
     if header_names["sus_im"] in ['AC X" (emu/Oe)', "AC X'' (emu/Oe)"]:
         in_susc_units = "emu/Oe"
@@ -83,6 +79,22 @@ def ac_mode_func(args):
         field_thresh=args.field_thresh
     )
 
+    if args.verbose:
+        print('\nVerbose mode entered.\n')
+        for experiments in all_experiments_sep:
+            print('Field: {} Oe'.format(experiments[0].dc_field))
+            print('The raw temperatures at this field have been grouped as:') # noqa
+            for experiment in experiments:
+                print(
+                    'Mean={:04.1f}, Min={}, Max={}\nRaw={}'.format(
+                        experiment.temperatures[0],
+                        np.min(experiment.raw_temperatures),
+                        np.max(experiment.raw_temperatures),
+                        experiment.raw_temperatures
+                    )
+                )
+                print('{} Frequencies: {}\n'.format(len(experiment.ac_freq), experiment.ac_freq))
+
     if args.process == "plot":
         for experiments in all_experiments_sep:
             ac.Experiment.plot_colecole(
@@ -116,7 +128,7 @@ def ac_mode_func(args):
     for experiments, dc_field in zip(all_experiments_sep, unique_dc_fields):
 
         # Creates models for current experiments
-        models = ac.Model.from_experiments(experiments)
+        models = ac.Model.from_experiments(experiments, verbose=True)
         # Update flat lines threshold
         for model in models:
             model.flat_thresh = args.flat_thresh
@@ -350,7 +362,8 @@ def dc_mode_func(args):
                 exe_mode='dc',
                 results_dir="{}_results".format(
                     os.path.splitext(args.input_file)[0]
-                ).replace(".", "_")
+                ).replace(".", "_"),
+                verbose=args.verbose
             )
 
             # Read-in the rates.
@@ -391,7 +404,8 @@ def relaxation_mode_func(args):
         sigma=args.sigma,
         results_dir="{}_results".format(
             os.path.splitext(args.input_file)[0]
-        ).replace(".", "_")
+        ).replace(".", "_"),
+        verbose=args.verbose
     )
 
     # Read-in the rates.
@@ -619,6 +633,20 @@ def read_args(arg_list=None):
         help='Print the read-in values from the file indicated.'
     )
 
+    # Hidden argument to signify that AC is being run by the executable
+    # version of ccfit2
+    if "--ccfit2_exe" in sys.argv:
+        parser.add_argument(
+            '--ccfit2_exe',
+            action='store_true',
+            help=""
+        )
+
+    args = parser.parse_args()
+
+    if "--ccfit2_exe" not in sys.argv:
+        args.run = False
+
     # Waveform
     description_Waveform = """
     Extract AC susceptibilities from waveform data
